==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_solutionhealthrulesetCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_solutionhealthruleset;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_analysiscomponentRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_solutionhealthruleRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_solutionhealthrulesetRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class Msdyn_solutionhealthrulesetCollectionRequest extends CollectionPageEntityRequest<Msdyn_solutionhealthruleset, Msdyn_solutionhealthrulesetRequest>{

    protected ContextPath contextPath;

    public Msdyn_solutionhealthrulesetCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_solutionhealthruleset.class, cp -> new Msdyn_solutionhealthrulesetRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_solutionhealthruleset_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_solutionhealthruleset_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_solutionhealthruleset_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_solutionhealthruleset_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_solutionhealthruleset_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_solutionhealthruleset_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_solutionhealthruleset_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_solutionhealthruleset_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_solutionhealthruleset_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_solutionhealthruleset_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_solutionhealthruleset_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_solutionhealthruleset_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_solutionhealthruleset_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_solutionhealthruleset_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_solutionhealthruleset_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_solutionhealthruleset_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_solutionhealthruleset_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_solutionhealthruleset_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_solutionhealthruleset_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_solutionhealthruleset_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_solutionhealthruleset_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_solutionhealthruleset_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_solutionhealthruleset_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public Msdyn_analysiscomponentCollectionRequest msdyn_msdyn_solutionhealthruleset_msdyn_analysi() {
        return new Msdyn_analysiscomponentCollectionRequest(contextPath.addSegment("msdyn_msdyn_solutionhealthruleset_msdyn_analysi"), Optional.empty());
    }

    public Msdyn_analysiscomponentRequest msdyn_msdyn_solutionhealthruleset_msdyn_analysi(String msdyn_analysiscomponentid) {
        return new Msdyn_analysiscomponentRequest(contextPath.addSegment("msdyn_msdyn_solutionhealthruleset_msdyn_analysi").addKeys(new NameValue(msdyn_analysiscomponentid.toString())), Optional.empty());
    }

    public Msdyn_solutionhealthruleCollectionRequest msdyn_msdyn_solutionhealthruleset_msdyn_solutio() {
        return new Msdyn_solutionhealthruleCollectionRequest(contextPath.addSegment("msdyn_msdyn_solutionhealthruleset_msdyn_solutio"), Optional.empty());
    }

    public Msdyn_solutionhealthruleRequest msdyn_msdyn_solutionhealthruleset_msdyn_solutio(String msdyn_solutionhealthruleid) {
        return new Msdyn_solutionhealthruleRequest(contextPath.addSegment("msdyn_msdyn_solutionhealthruleset_msdyn_solutio").addKeys(new NameValue(msdyn_solutionhealthruleid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_solutionhealthrulesetCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_solutionhealthruleset;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_analysiscomponentRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_solutionhealthruleRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_solutionhealthrulesetRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class Msdyn_solutionhealthrulesetCollectionRequest extends CollectionPageEntityRequest<Msdyn_solutionhealthruleset, Msdyn_solutionhealthrulesetRequest>{

    protected ContextPath contextPath;

    public Msdyn_solutionhealthrulesetCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_solutionhealthruleset.class, cp -> new Msdyn_solutionhealthrulesetRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_solutionhealthruleset_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_solutionhealthruleset_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_solutionhealthruleset_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_solutionhealthruleset_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_solutionhealthruleset_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_solutionhealthruleset_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_solutionhealthruleset_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_solutionhealthruleset_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_solutionhealthruleset_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_solutionhealthruleset_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_solutionhealthruleset_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_solutionhealthruleset_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_solutionhealthruleset_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_solutionhealthruleset_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_solutionhealthruleset_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_solutionhealthruleset_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_solutionhealthruleset_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_solutionhealthruleset_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_solutionhealthruleset_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_solutionhealthruleset_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_solutionhealthruleset_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_solutionhealthruleset_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_solutionhealthruleset_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_solutionhealthruleset_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public Msdyn_analysiscomponentCollectionRequest msdyn_msdyn_solutionhealthruleset_msdyn_analysi() {
        return new Msdyn_analysiscomponentCollectionRequest(contextPath.addSegment("msdyn_msdyn_solutionhealthruleset_msdyn_analysi"), Optional.empty());
    }

    public Msdyn_analysiscomponentRequest msdyn_msdyn_solutionhealthruleset_msdyn_analysi(String msdyn_analysiscomponentid) {
        return new Msdyn_analysiscomponentRequest(contextPath.addSegment("msdyn_msdyn_solutionhealthruleset_msdyn_analysi").addKeys(new NameValue(msdyn_analysiscomponentid.toString())), Optional.empty());
    }

    public Msdyn_solutionhealthruleCollectionRequest msdyn_msdyn_solutionhealthruleset_msdyn_solutio() {
        return new Msdyn_solutionhealthruleCollectionRequest(contextPath.addSegment("msdyn_msdyn_solutionhealthruleset_msdyn_solutio"), Optional.empty());
    }

    public Msdyn_solutionhealthruleRequest msdyn_msdyn_solutionhealthruleset_msdyn_solutio(String msdyn_solutionhealthruleid) {
        return new Msdyn_solutionhealthruleRequest(contextPath.addSegment("msdyn_msdyn_solutionhealthruleset_msdyn_solutio").addKeys(new NameValue(msdyn_solutionhealthruleid.toString())), Optional.empty());
    }

}
